@@ -40,9 +40,9 @@ typedef Eo Efl_Gfx_Stack;
 EWAPI const Efl_Class *efl_gfx_stack_interface_get(void);
 
 /**
- * @brief Sets the layer of its canvas that the given object will be part of.
+ * @brief The layer of its canvas that the given object will be part of.
  *
- * If you don't use this function, you'll be dealing with an unique layer of
+ * If you don't use this property, you'll be dealing with a unique layer of
  * objects (the default one). Additional layers are handy when you don't want a
  * set of objects to interfere with another set with regard to stacking. Two
  * layers are completely disjoint in that matter.
@@ -53,8 +53,6 @@ EWAPI const Efl_Class *efl_gfx_stack_interface_get(void);
  * @warning Don't change the layer of smart objects' children. Smart objects
  * have a layer of their own, which should contain all their child objects.
  *
- * See also @ref efl_gfx_stack_layer_get()
- *
  * @param[in] obj The object.
  * @param[in] l The number of the layer to place the object on. Must be between
  * @ref EFL_GFX_STACK_LAYER_MIN and @ref EFL_GFX_STACK_LAYER_MAX.
@@ -66,9 +64,18 @@ EWAPI const Efl_Class *efl_gfx_stack_interface_get(void);
 EOAPI void efl_gfx_stack_layer_set(Eo *obj, short l);
 
 /**
- * @brief Retrieves the layer of its canvas that the given object is part of.
+ * @brief The layer of its canvas that the given object will be part of.
  *
- * See also @ref efl_gfx_stack_layer_set()
+ * If you don't use this property, you'll be dealing with a unique layer of
+ * objects (the default one). Additional layers are handy when you don't want a
+ * set of objects to interfere with another set with regard to stacking. Two
+ * layers are completely disjoint in that matter.
+ *
+ * This is a low-level function, which you'd be using when something should be
+ * always on top, for example.
+ *
+ * @warning Don't change the layer of smart objects' children. Smart objects
+ * have a layer of their own, which should contain all their child objects.
  *
  * @param[in] obj The object.
  *
@@ -82,13 +89,12 @@ EOAPI void efl_gfx_stack_layer_set(Eo *obj, short l);
 EOAPI short efl_gfx_stack_layer_get(const Eo *obj);
 
 /**
- * @brief Get the Evas object stacked right below @c obj
+ * @brief The Evas object stacked right below this object.
  *
  * This function will traverse layers in its search, if there are objects on
  * layers below the one @c obj is placed at.
  *
- * See also @ref efl_gfx_stack_layer_get(), @ref efl_gfx_stack_layer_set() and
- * @ref efl_gfx_stack_below_get()
+ * See also @ref efl_gfx_stack_layer_get.
  *
  * @param[in] obj The object.
  *
@@ -102,13 +108,12 @@ EOAPI short efl_gfx_stack_layer_get(const Eo *obj);
 EOAPI Efl_Gfx_Stack *efl_gfx_stack_below_get(const Eo *obj) EINA_WARN_UNUSED_RESULT;
 
 /**
- * @brief Get the Evas object stacked right above @c obj
+ * @brief Get the Evas object stacked right above this object.
  *
  * This function will traverse layers in its search, if there are objects on
  * layers above the one @c obj is placed at.
  *
- * See also @ref efl_gfx_stack_layer_get(), @ref efl_gfx_stack_layer_set() and
- * @ref efl_gfx_stack_below_get()
+ * See also @ref efl_gfx_stack_layer_get and @ref efl_gfx_stack_below_get
  *
  * @param[in] obj The object.
  *
@@ -148,7 +153,7 @@ EOAPI Efl_Gfx_Stack *efl_gfx_stack_above_get(const Eo *obj) EINA_WARN_UNUSED_RES
  *
  * @ingroup Efl_Gfx_Stack
  */
-EOAPI void efl_gfx_stack_below(Eo *obj, Efl_Gfx_Stack *below) EINA_ARG_NONNULL(2);
+EOAPI void efl_gfx_stack_below(Eo *obj, Efl_Gfx_Stack *below);
 
 /**
  * @brief Raise @c obj to the top of its layer.
@@ -194,7 +199,7 @@ EOAPI void efl_gfx_stack_raise_to_top(Eo *obj);
  *
  * @ingroup Efl_Gfx_Stack
  */
-EOAPI void efl_gfx_stack_above(Eo *obj, Efl_Gfx_Stack *above) EINA_ARG_NONNULL(2);
+EOAPI void efl_gfx_stack_above(Eo *obj, Efl_Gfx_Stack *above);
 
 /**
  * @brief Lower @c obj to the bottom of its layer.
