@@ -4,9 +4,10 @@
 #ifndef _EFL_UI_TYPES_EOT_TYPES
 #define _EFL_UI_TYPES_EOT_TYPES
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Permitted directions for dragging objects.
  *
- * @ingroup Efl_Ui_Drag
+ * @ingroup Efl_Ui
  */
 typedef enum
 {
@@ -15,6 +16,7 @@ typedef enum
   EFL_UI_DRAG_DIR_Y = 2, /**< Draggable vertically. */
   EFL_UI_DRAG_DIR_XY = 3 /**< Draggable in both directions. */
 } Efl_Ui_Drag_Dir;
+#endif /* EFL_BETA_API_SUPPORT */
 
 
 #endif
