@@ -13,6 +13,7 @@ typedef Eo Eldbus_Model_Signal;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Eldbus model signal class
  *
  * @ingroup Eldbus_Model_Signal
@@ -33,5 +34,6 @@ EWAPI const Efl_Class *eldbus_model_signal_class_get(void);
  * @ingroup Eldbus_Model_Signal
  */
 EOAPI void eldbus_model_signal_constructor(Eo *obj, Eldbus_Proxy *proxy, const Eldbus_Introspection_Signal *signal);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
