@@ -13,16 +13,14 @@ typedef Eo Efl_Ui_List_Default_Item;
 
 
 #endif
-#ifdef EFL_BETA_API_SUPPORT
-/** List Default Item class. This class need to be sub object of list widget.
- * text and contents can be appliable by efl_text, efl_content or efl_part
- * APIs.
+/** Default Item class to be used inside @ref Efl_Ui_List containers. It
+ * displays the three parts in horizontal order: @c icon, @c text and @c extra.
+ * Theming can change this arrangement.
  *
  * @ingroup Efl_Ui_List_Default_Item
  */
 #define EFL_UI_LIST_DEFAULT_ITEM_CLASS efl_ui_list_default_item_class_get()
 
 EWAPI const Efl_Class *efl_ui_list_default_item_class_get(void);
-#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
