@@ -23,7 +23,7 @@ typedef Eo Efl_Canvas_Vg_Node;
 EWAPI const Efl_Class *efl_canvas_vg_node_class_get(void);
 
 /**
- * @brief Sets the transformation matrix to be used for this node object.
+ * @brief The transformation matrix to be used for this node object.
  *
  * @note Pass @c null to cancel the applied transformation.
  *
@@ -35,7 +35,9 @@ EWAPI const Efl_Class *efl_canvas_vg_node_class_get(void);
 EOAPI void efl_canvas_vg_node_transformation_set(Eo *obj, const Eina_Matrix3 *m);
 
 /**
- * @brief Gets the transformation matrix used for this node object.
+ * @brief The transformation matrix to be used for this node object.
+ *
+ * @note Pass @c null to cancel the applied transformation.
  *
  * @param[in] obj The object.
  *
@@ -46,7 +48,7 @@ EOAPI void efl_canvas_vg_node_transformation_set(Eo *obj, const Eina_Matrix3 *m)
 EOAPI const Eina_Matrix3 *efl_canvas_vg_node_transformation_get(const Eo *obj);
 
 /**
- * @brief Sets the origin position of the node object.
+ * @brief The origin position of the node object.
  *
  * This origin position affects node transformation.
  *
@@ -59,7 +61,9 @@ EOAPI const Eina_Matrix3 *efl_canvas_vg_node_transformation_get(const Eo *obj);
 EOAPI void efl_canvas_vg_node_origin_set(Eo *obj, double x, double y);
 
 /**
- * @brief Gets the origin position of the node object.
+ * @brief The origin position of the node object.
+ *
+ * This origin position affects node transformation.
  *
  * @param[in] obj The object.
  * @param[out] x @c origin x position.
@@ -70,15 +74,15 @@ EOAPI void efl_canvas_vg_node_origin_set(Eo *obj, double x, double y);
 EOAPI void efl_canvas_vg_node_origin_get(const Eo *obj, double *x, double *y);
 
 /**
- * @brief Set Mask Node to this renderer
+ * @brief Set a composite target node to this node object.
  *
  * @param[in] obj The object.
- * @param[in] mask Mask object
- * @param[in] op Masking Option. Reserved
+ * @param[in] target Composite target node
+ * @param[in] method Composite Method.
  *
  * @ingroup Efl_Canvas_Vg_Node
  */
-EOAPI void efl_canvas_vg_node_mask_set(Eo *obj, Efl_Canvas_Vg_Node *mask, int op);
+EOAPI void efl_canvas_vg_node_comp_method_set(Eo *obj, Efl_Canvas_Vg_Node *target, Efl_Gfx_Vg_Composite_Method method);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
